<?php
/**
 * technerd Customizer functionality
 *
 * @package WordPress
 * @subpackage technerd
 * @since technerd 1.0
 */

/** Add Support for Custom Backgrounds & Headers */
add_theme_support( 'custom-background' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function technerd_customize_preview_js() {
	wp_enqueue_script( 'technerd_customizer', get_template_directory_uri() . '/assets/js/theme-customizer.js', array( 'customize-preview' ), '1.0.0', true );
}
add_action( 'customize_preview_init', 'technerd_customize_preview_js' );

/**
 * Technerd Options.
 */
function technerd_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';

	// Primary/Link Color
	$wp_customize->add_setting( 'primary_color', array(
		'sanitize_callback' => 'sanitize_hex_color'
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'primary_color', array(
		'label'       => __( 'Primary/Link Color', 'technerd' ),
		'section'     => 'colors',
		'description' => __( 'The primary link/button color for the content area.', 'technerd' )
	) ) );

	// Secondary Color
	$wp_customize->add_setting( 'secondary_color', array(
		'default'           => '#009d9f',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'secondary_color', array(
		'label'       => __( 'Secondary Color', 'technerd' ),
		'section'     => 'colors',
		'description' => __( 'A highlight color for odds/ends: category links, header navigation rollovers, and a couple other things.', 'technerd' )
	) ) );

	// Header Background Color
	$wp_customize->add_setting( 'header_bg_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_bg_color', array(
		'label'       => __( 'Header Background Color', 'technerd' ),
		'section'     => 'colors',
		'description' => __( 'The background color of the header.', 'technerd' )
	) ) );

	// Header Background Color
	$wp_customize->add_setting( 'header_text_color', array(
		'default'           => '#333',
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'header_text_color', array(
		'label'       => __( 'Header Text Color', 'technerd' ),
		'section'     => 'colors',
		'description' => __( 'The color of the header text (logo, description, icons).', 'technerd' )
	) ) );

	// Create social URL section
	
	$wp_customize->add_section( 'technerd_social_urls' , array(
    'title'      => __('Social Urls','technerd'),
    'priority'   => 85,
	) );

	// Facebook URL
	$wp_customize->add_setting( 'facebook_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'facebook_url', array(
		'label'       => __( 'Facebook Url', 'technerd' ),
		'section'     => 'technerd_social_urls',
	) ) );

	// Twitter URL
	$wp_customize->add_setting( 'twitter_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'twitter_url', array(
		'label'       => __( 'Twitter Url', 'technerd' ),
		'section'     => 'technerd_social_urls',
	) ) );

	// Pinterest URL
	$wp_customize->add_setting( 'pinterest_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'pinterest_url', array(
		'label'       => __( 'Pinterest Url', 'technerd' ),
		'section'     => 'technerd_social_urls',
	) ) );

	// Linked In URL
	$wp_customize->add_setting( 'linkedin_url', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'linkedin_url', array(
		'label'       => __( 'LinkedIn Url', 'technerd' ),
		'section'     => 'technerd_social_urls',
	) ) );

 // Create Flexslider section
	
	$wp_customize->add_section( 'technerd_slider_settings' , array(
    'title'      => __('Slider','technerd'),
    'priority'   => 80,
	) );

	$wp_customize->add_setting( 'enable_slider', array(
		'default'           => false,
		'sanitize_callback' => 'technerd_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'enable_slider', array(
		'label'       => __( 'Check to enable/disable slider', 'technerd' ),
		'section'     => 'technerd_slider_settings',
		'type'			  => 'checkbox'
	) );

	// Footer Message
	
	$wp_customize->add_section( 'technerd_footer_settings' , array(
    'title'      => __('Footer Message','technerd'),
    'priority'   => 80,
	) );

	$wp_customize->add_setting( 'footer_message', array(
		'default'           => '',
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'footer_message', array(
		'label'       => __( 'Footer Message', 'technerd' ),
		'section'     => 'technerd_footer_settings',
		'type' 				=> 'textarea'
	) ) );

}
add_action( 'customize_register', 'technerd_customize_register' );

/* Sanitize Callbacks */

function technerd_sanitize_checkbox( $input ) {
	return ( ( isset( $input ) && true == $input ) ? true : false );
}

/* Add New CSS */

function technerd_customize_css()
{
	?>
		<style type="text/css">

		/* Primary Color */
		a,
		.flexslider .slides .excerpt a.read-more-excerpt { color:<?php echo esc_html(  get_theme_mod('primary_color', '#cc0000') ); ?>; }

		input[type="submit"],
		.pagination .page-numbers.current,
		.page-header { background-color:<?php echo esc_html( get_theme_mod('primary_color', '#cc0000') ); ?>; }

		/* Secondary Color */

		.entry-category a, 
		.sticky-message::before,
		.widget ul li.recentcomments:before,
		.social-links a:hover,
		.site-nav ul li.current-menu-item a { color:<?php echo esc_html( get_theme_mod('secondary_color', '#cc0000') ); ?>; }

		.site-nav ul li a:hover,
		.pagination .page-numbers:hover { background-color:<?php echo esc_html( get_theme_mod('secondary_color', '#cc0000') ); ?>; }

		/* Header Background Color */

		.site-branding { background-color:<?php echo esc_html( get_theme_mod('header_bg_color', '#ffffff') ); ?>; }

		/* Header Text Color */

		.site-title a,
		.site-description,
		.social-links a,
		.nav-toggle { color:<?php echo esc_html( get_theme_mod('header_text_color', '#333') ); ?>; }

		</style>
	<?php
}
add_action( 'wp_head', 'technerd_customize_css');